summaryrefslogtreecommitdiffstats
path: root/languages/cpp/app_templates/qtopiaapp/example.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'languages/cpp/app_templates/qtopiaapp/example.cpp')
-rw-r--r--languages/cpp/app_templates/qtopiaapp/example.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/languages/cpp/app_templates/qtopiaapp/example.cpp b/languages/cpp/app_templates/qtopiaapp/example.cpp
index a849977d..85082508 100644
--- a/languages/cpp/app_templates/qtopiaapp/example.cpp
+++ b/languages/cpp/app_templates/qtopiaapp/example.cpp
@@ -3,11 +3,11 @@
#include <tqpushbutton.h>
/*
* Constructs a %{APPNAME} which is a child of 'parent', with the
* name 'name' and widget flags set to 'f'
*/
-%{APPNAME}::%{APPNAME}( TQWidget* parent, const char* name, WFlags fl )
- : %{APPNAME}Base( parent, name, fl )
+%{APPNAME}::%{APPNAME}( TQWidget* tqparent, const char* name, WFlags fl )
+ : %{APPNAME}Base( tqparent, name, fl )
{
connect(quit, TQT_SIGNAL(clicked()), this, TQT_SLOT(goodBye()));
}
@@ -17,7 +17,7 @@
*/
%{APPNAME}::~%{APPNAME}()
{
- // no need to delete child widgets, Qt does it all for us
+ // no need to delete child widgets, TQt does it all for us
}
/*
@@ -3,11 +3,11 @@
#include <tqpushbutton.h>
/*
- * Constructs a %{APPNAME} which is a child of 'parent', with the
+ * Constructs a %{APPNAME} which is a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'
*/